'''
@author: jose.corsini
'''
import numpy
from pyper import R
from cluster.ClusterOutput import ClusterOutput
from web import UserFilesController

#Constroi um cluster a partir dos parametros fornecidos pelo usuario
def buildCluster(username, items, num_centers, title, subtitle, xLabel, yLabel):

    x = [[items[0].xValue, items[0].yValue]]
    for i in range(len(items) - 1):
        it = items[i+1]
        x = numpy.concatenate((x, [[it.xValue,it.yValue]]), 0)
    
    myR = R() 
    
    #Cria a matriz no R
    myR['m'] = x
    
    #Define o nome nas colunas
    colNames = 'colnames(m) <- c("'+xLabel+'", "'+yLabel+'")' 
    myR.run(colNames)

    #cl recebe os resultados do kmeans sobre a matriz "m" para 'centers' grupos
    kmeans = 'cl <- kmeans(m, '+str(num_centers)+')'
    myR.run(kmeans)
    
    #busca os valores obtidos no cluster
    size = myR['cl$size']
    cluster = myR['cl$cluster']
    centers = myR['cl$centers']
    
    
    
    # Cria o output
    outputContainer = ClusterOutput(username, num_centers)
    
    # Seta os valores referentes a cada grupo
    for i in range(len(centers)):
        outputContainer.setGroupValues(i, size[i], centers[i][0], centers[i][1])
    
    
    # Insere o item no grupo respectivamente (o menos '1' ocorre pois o identificador comeca em 1)
    for j in range(len(items)):
        outputContainer.insertItem(cluster[j] - 1, items[j])
    


    # Gera imagem saida    
    outputPath = UserFilesController.generateRandomOutputFilePath(username, '.png')
    outputContainer.clusterImage = outputPath
    output = "png('" + outputPath + "')"
    myR.run(output)
    
    
    #plota os pontos da matriz m
    plot = 'plot(m, col = cl$cluster)'
    myR.run(plot)


    
    return outputContainer
    