'''
@author: jose.corsini
'''
from web import UserFilesController

#Cria o arquivo de exportacao (saida) de remocao de outliers 
def exportMahalanobisAnalysis(username, outputContainer):
    analysisFile = UserFilesController.generateRandomOutputFilePath(username, ".txt")
    f = open(analysisFile, 'w')
    writeHeader(f)

    f.write('####################################################### \n')
    f.write('####               FUNDOS PRESERVADOS              #### \n' )         
    f.write('####################################################### \n\n')
    preservedCNPJ = outputContainer.preservedCNPJ
    for i in range(len(preservedCNPJ)):
        f.write(preservedCNPJ[i] + '\n')
    
    f.write('\n\n\n####################################################### \n')
    f.write('####          FUNDOS REMOVIDOS (OUTLIERS)          #### \n' )         
    f.write('####################################################### \n\n')
    removedCNPJ = outputContainer.removedCNPJ
    for i in range(len(removedCNPJ)):
        f.write(removedCNPJ[i] + '\n')
    
    f.close() 
    outputContainer.analysisFile = analysisFile
    
#Cria o arquivo de exportacao (saida) da classificacao dos fundos    
def exportClusterAnalysis(username, outputContainer):
    analysisFile = UserFilesController.generateRandomOutputFilePath(username, ".txt")
    f = open(analysisFile, 'w')
    writeHeader(f)
    
    f.write('####################################################### \n')
    f.write('####                   PARAMETROS                  #### \n' )         
    f.write('####################################################### \n\n')
    f.write("CENTROIDES: " + str(outputContainer.num_centers) + "\n")

    f.write('\n\n####################################################### \n')
    f.write('####                GRUPOS DEFINIDOS               #### \n' )         
    f.write('####################################################### \n\n')
    
    groups = outputContainer.outputGroups
    for i in range(len(groups)):
        g = groups[i]
        
        f.write('\n\n-------------------------------------------------------\n' )
        f.write('GRUPO: '+ str(g.groupIdentifier)+' \n')
        f.write('TAMANHO: '+str(g.size)+' itens \n') 
        f.write('CENTROIDE: ('+str(g.xCenter)+';'+str(g.yCenter)+')')
        f.write('\n-------------------------------------------------------\n' )
        
        f.write('\nFUNDO;VALOR_X;VALOR_Y\n' )
        items = g.items
        for j in range(len(items)):
            it = items[j]
            f.write(it.cnpj +';'+str(it.xValue)+';'+str(it.yValue)+ '\n')
    
    f.close()
    outputContainer.analysisFile = analysisFile

#Cria o arquivo de exportacao (saida) de relatorios processados
def exportReport(username, outputContainer):
    reportFile = UserFilesController.generateRandomOutputFilePath(username, ".txt")
    f = open(reportFile, 'w')
    writeHeader(f)
    
    f.write('####################################################### \n')
    f.write('####                   PARAMETROS                  #### \n' )         
    f.write('####################################################### \n\n')
    f.write("DATA: " + outputContainer.date + "\n")
    f.write("PERIODOS: " + outputContainer.periods + "\n")
    f.write("INDICADORES: " + outputContainer.indicators + "\n")

    f.write('\n\n####################################################### \n')
    f.write('####                VALORES OBTIDOS                #### \n' )         
    f.write('####################################################### \n\n')
    
    f.write('\nFUNDO;INDICADOR;PERIODO;VALOR\n' )
    items = outputContainer.items
    for it in items:
        f.write(str(it.cnpj) + ';' + str(it.item.indicatorType) + ';' + str(getIndicatorType(it.item.periodType)) + ';' + str(it.item.value) + '\n')
    
    f.close()
    outputContainer.reportFile = reportFile
    
def getIndicatorType(days):
    if(days == '21'):
        return '1M'
    elif(days == '63'):
        return '3M'
    elif(days == '126'):
        return '6M'
    elif(days == '252'):
        return '1A'
    
def writeHeader(f):
    f.write('####################################################### \n')
    f.write('####  ANALISE GERADA PELO SISTEMA FUND CLUSTERING  #### \n')
    f.write('####################################################### \n\n\n')