'''
@author: jose.corsini
'''
import busca_info
from util.Quota import Quota
from util.Fund import Fund
from util.Benchmark import Benchmark
from util.BenchmarkValue import BenchmarkValue
from util.FundCalculatedData import FundCalculatedData
from util.FundCalculatedDataItem import FundCalculatedDataItem

#Busca a lista de cnpj para todos os fundos
def buscaListaCNPJTodosFundos():
    l = []
    cnpjList = busca_info.buscaCNPJTodosFundos()
    for cnpj in cnpjList.fetchall():
        l.append(cnpj[0])
    
    return l    

#Busca a lista de fundos de uma categoria
def buscaListaFundosCategoria(categoria):
    fundos = busca_info.buscaFundosDeCategoria(categoria)
    a = fundos;
    return a

#Busca a serie de cotas de um fundo
def buscaListaQuotasFundo(cnpj):
    l = []
    quotas = busca_info.buscaSerieCotasDoFundo(cnpj)
    
    for q in quotas.fetchall():
        l.append(Quota(q[0], q[1], q[2]))
        
    return l

#Busca fundo por cnpj
def buscaFundo(cnpj):
    f = busca_info.buscaFundo(cnpj).fetchall()
    if(len(f) == 0):
        return None
    else:
        f = f[0]
        fund = Fund(f[0],f[1],f[2],f[3],f[4]);
        return fund
    
    
#Busca um benchmark por simbolo
def buscaBenchmark(symbol):
    b = busca_info.buscaBenchmark(symbol).fetchall()
    
    if(len(b) == 0):
        return None
    else:
        b = b[0]
        bench = Benchmark(b[0],b[1],b[2])
        return bench

#Busca a serie de valores do benchmark
def buscaListaIndicesBench(symbol):
    l = []
    values = busca_info.buscaSerieIndice(symbol)
    
    for v in values.fetchall():
        l.append(BenchmarkValue(v[0], v[1], v[2]))
        
    return l

#Busca o indice de um benchmark para uma determinada data
def buscaIndiceBenchData(symbol, date):
    bv = busca_info.buscaSerieIndiceData(symbol, date).fetchall()
    if(len(bv) == 0):
        return None
    else:
        bv = bv[0]
        benchValue = BenchmarkValue(bv[0], bv[1], bv[2])
        return benchValue
    
#Atualiza ou persiste o valor de um indice de benchmark
def atualizaOuPersisteBenchValue(symbol, date, value):
    bv = buscaIndiceBenchData(symbol,  date)
    if(bv == None):
        bench = buscaBenchmark(symbol)
        if(bench == None):
            return
        else:
            busca_info.persisteValorIndiceData(bench.benchId, date, value)
    else:
        busca_info.updateValorIndice(bv.benchValueId, value)
        
#Insere um novo benchmark
def persisteNovoBench(symbol, description):
    busca_info.insertNovoBenchmark(symbol, description)
    
#Insere um item calculado para um fundo e uma data
def persistCalculatedData(fundId, date):
    busca_info.persistCalculatedData(fundId, date)
    
#Busca um item calculado por fundo e data
def findCalculatedDataByFundDate(fundId, date):
    data = busca_info.findCalculatedDataByFundDate(fundId, date).fetchall()
    if(len(data) == 0):
        return None
    else:
        data = data[0]
        fundCalcData = FundCalculatedData(data[0], data[1], data[2])
        return fundCalcData

#Insere um indicador calculado
def persistCalculatedIndicator(calculatedIndicator):
    busca_info.persistCalculatedIndicator(calculatedIndicator)    

#Busca o ultimo indicador calculado para um fundo
def searchLastCalculatedDataByFund(fundId):
    data = busca_info.searchCalculatedDataByFundOrderByDateDesc(fundId).fetchall()
    if(len(data) == 0):
        return None
    else:
        data = data[0]
        fundCalcData = FundCalculatedData(data[0], data[1], data[2])
        return fundCalcData
    
#Busca todos indicadores calculados de um fundo para uma data 
def searchFundCalculatedDataItemsByData(fundCalculatedData):
    l = []
    quotas = busca_info.searchFundCalculatedDataItemsByData(fundCalculatedData.dataId)
    
    for q in quotas.fetchall():
        l.append(FundCalculatedDataItem(fundCalculatedData, q[0], q[1], q[2], q[3]))
        
    return l

    