'''
@author: jose.corsini
'''
# Importa o modulo de conexao com o mysql
import MySQLdb

# Gera a string de conexao
db = MySQLdb.connect(host="localhost", user="root", passwd="root", db="cvm_fund_info")

#Para cada metodo, eh realizado o posicionamento do cursor
#Esta classe e a implementacao dos selects e inserts nativos

def buscaCNPJTodosFundos():
    cursor = db.cursor()
    cursor.execute("SELECT cnpj FROM cvm_fund_info.fund",())
    db.commit()
    return cursor

def buscaFundosDeCategoria(category):
    cursor = db.cursor()
    cursor.execute("SELECT cnpj,name FROM cvm_fund_info.fund WHERE category = %s", (category,))
    db.commit()
    return cursor

def buscaFundo(cnpj):
    cursor = db.cursor()
    cursor.execute("SELECT id,cnpj,name,start_date,category from fund f where f.cnpj = %s", (cnpj,))
    db.commit()
    return cursor 

def buscaSerieCotasDoFundo(cnpj):
    cursor = db.cursor()
    cursor.execute("SELECT date,quota,net_asset FROM cvm_fund_info.fund_quota q join cvm_fund_info.fund  f on q.fund_id = f.id WHERE f.cnpj = %s order by date asc", (cnpj,))
    db.commit()
    return cursor

def buscaBenchmark(symbol):
    cursor = db.cursor()
    cursor.execute("SELECT id,symbol,description from benchmark b where b.symbol = %s", (symbol,))
    db.commit()
    return cursor

def buscaSerieIndice(symbol):
    cursor = db.cursor()
    cursor.execute("SELECT bv.id,date,value FROM cvm_fund_info.benchmark_value bv join cvm_fund_info.benchmark  b on bv.benchmark_id = b.id WHERE b.symbol = %s order by date asc", (symbol,))
    db.commit()
    return cursor

def buscaSerieIndiceData(symbol,date):
    cursor = db.cursor()
    cursor.execute("SELECT bv.id,date,value FROM cvm_fund_info.benchmark_value bv join cvm_fund_info.benchmark  b on bv.benchmark_id = b.id WHERE b.symbol = %s and date = %s", (symbol, date))
    db.commit()
    return cursor

def persisteValorIndiceData(benchId,date, value):
    cursor = db.cursor()
    cursor.execute("INSERT INTO benchmark_value (benchmark_id, date, value) values (%s,%s,%s)", (benchId, date, value,))
    db.commit()
    
    
def updateValorIndice(benchValueId, value):
    cursor = db.cursor()
    cursor.execute("UPDATE benchmark_value SET value = %s where id = %s", (value,benchValueId,))
    db.commit()
    
def insertNovoBenchmark(symbol, description):
    cursor = db.cursor()
    cursor.execute("INSERT INTO benchmark (symbol, description) values (%s,%s)", (symbol, description,))
    db.commit()
    
def persistCalculatedData(fundId, date):
    cursor = db.cursor()
    cursor.execute("INSERT INTO fund_calculated_data (fund_id, date) values (%s,%s)", (fundId, date,))
    db.commit()
    
def findCalculatedDataByFundDate(fundId, date):
    cursor = db.cursor()
    cursor.execute("SELECT id, fund_id, date FROM fund_calculated_data fc WHERE fund_id = %s and date = %s", (fundId, date))
    db.commit()
    return cursor

def searchCalculatedDataByFundOrderByDateDesc(fundId):
    cursor = db.cursor()
    cursor.execute("SELECT id, fund_id, date FROM fund_calculated_data fc WHERE fund_id = %s order by date desc", (fundId,))
    db.commit()
    return cursor

def persistCalculatedIndicator(calculatedIndicator):
    cursor = db.cursor()
    cursor.execute("INSERT INTO fund_calculated_data_item (calculated_data_id, indicator_type, period_type, value, benchmark_id) values (%s,%s,%s,%s,%s)", (calculatedIndicator.fundCalculatedData.dataId, calculatedIndicator.indicatorType,calculatedIndicator.periodType,calculatedIndicator.value,calculatedIndicator.benchId,))
    db.commit()
    
def searchFundCalculatedDataItemsByData(fundCalculatedDataId):
    cursor = db.cursor()
    cursor.execute("SELECT indicator_type, period_type, value, benchmark_id FROM fund_calculated_data_item WHERE calculated_data_id = %s", (fundCalculatedDataId,))
    db.commit()
    return cursor
     

