'''
@author: jose.corsini
'''
from flask import Flask, url_for, redirect, request, session, render_template
from web import UserFilesController
from mahalanobis import MahalanobisProcessor
from flask.helpers import flash
from cluster import ClusterProcessor
from admin import AdminUploader, ComputeIndicatorsProcessor
from analysis import SearchProcessor, ReportProcessor
from datetime import datetime

##################################################################################
# CLASSE QUE REPRESENTARA A APLICACAO WEB                                        #
# AQUI ESTAO CONTIDAS AS REGRAS DE NAVEGACAO E NEGOCIO UTILIZADAS NA CAMADA WEB  #
# AS CHAMADAS AOS PRINCIPAIS MODULOS PODEM SER VISTAS SEPARADAMENTE POR SECOES   #
##################################################################################


app = Flask(__name__)

############################
#### INDEX/LOGIN/LOGOUT ####
############################

@app.route('/')
def index():
    if 'username' in session: 
        return redirect(url_for('home'))
    return redirect(url_for('login'))

@app.route('/login', methods=['GET', 'POST'])
def login():
    
    if 'username' in session:
        return redirect(url_for('home'))    
    
    if request.method == 'POST':
        validate = request.form['username'] + '12'
        if(request.form['password'] == validate):
            session['username'] = request.form['username']
            session['logged_in'] = True
            session['has_mahalanobis_file'] = False
            session['has_cluster_file'] = False
            session['has_upload_index_file'] = False
            session['has_report_parameters_file'] = False
            #### TEMP ####
            UserFilesController.createDirectories(session['username'])
            ###############
            return redirect(url_for('home'))
        else:
            flash(u'Erro ao logar. Tente novamente', 'error')
            
    return render_template('login.html')

   
@app.route('/logout')
def logout():
    UserFilesController.removeDirectories(session['username'])
    session.pop('username', None)
    session['logged_in'] = False
    session['has_mahalanobis_file'] = False
    session['has_cluster_file'] = False
    session['has_upload_index_file'] = False
    session['has_report_parameters_file'] = False
    return redirect(url_for('index'))



##############
#### HOME ####
##############
@app.route('/home')
def home():
    if 'username' in session:
        return render_template('home.html', username=session['username'])
        #return 'Bem vindo %s' % escape(session['username'])
    return redirect(url_for('login'))


##############
#### MAHALANOBIS ####
##############
@app.route('/mahalanobis')
def mahalanobis():
    if 'username' in session:
        return render_template('mahalanobis.html', has_file = session['has_mahalanobis_file'], username=session['username'], module_name = 'Outliers (Mahalanobis)')
    return redirect(url_for('login'))



@app.route('/uploadmahalanobis', methods=['GET', 'POST'])
def upload_mahalanobis():
    if request.method == 'POST':
        f = request.files['mahalanobis_file']
        UserFilesController.saveUserUploadedFile(session['username'], f, UserFilesController.FileType.MAHALANOBIS_UPLOAD)
        session['has_mahalanobis_file'] = True
    return redirect(url_for('mahalanobis'))

@app.route('/uploadanothermahalanobisfile', methods=['GET', 'POST'])
def upload_anothermahalanobisfile():
    session['has_mahalanobis_file'] = False
    return redirect(url_for('mahalanobis'))


@app.route('/processmahalanobis', methods=['GET', 'POST'])
def process_mahalanobis():
    if request.method == 'POST':
        factor = request.form['mahalanobis_factor']
        
        if(factor == ''):
            flash(u'Fator obrigatorio. Utilize um numero positivo.', 'error')
            return redirect(url_for('mahalanobis'))
        
        factor = factor.replace(',','.')
        factorNumber = float(factor)
        if(factorNumber <= 0):
            flash(u'Fator invalido. Utilize um numero positivo.', 'error')
            return redirect(url_for('mahalanobis'))
        else:
            output = MahalanobisProcessor.processMahalanobis(session['username'], factor)
            return render_template('mahalanobis.html',username=session['username'], outputContainer= output, has_file = session['has_mahalanobis_file'], module_name = 'Outliers (Mahalanobis)')
    
        
#################
#### CLUSTER ####
#################
@app.route('/cluster')
def cluster():
    if 'username' in session:
        return render_template('cluster.html', has_file = session['has_cluster_file'], username=session['username'], module_name = 'Cluster (k-means)')
    return redirect(url_for('login'))



@app.route('/uploadcluster', methods=['GET', 'POST'])
def upload_cluster():
    if request.method == 'POST':
        f = request.files['cluster_file']
        UserFilesController.saveUserUploadedFile(session['username'], f, UserFilesController.FileType.CLUSTER_UPLOAD)
        session['has_cluster_file'] = True
    return redirect(url_for('cluster'))

@app.route('/uploadanotherclusterfile', methods=['GET', 'POST'])
def upload_anotherclusterfile():
    session['has_cluster_file'] = False
    return redirect(url_for('cluster'))


@app.route('/processcluster', methods=['GET', 'POST'])
def process_cluster():
    if request.method == 'POST':
        centers = request.form['kmeans_centers']
        
        if(centers == ''):
            flash(u'Numero centroides obrigatorio. Utilize um numero inteiro positivo.', 'error')
            return redirect(url_for('cluster'))
        
        centers = centers.replace(',','.')
        factorNumber = int(centers)
        if(factorNumber <= 0):
            flash(u'Fator invalido. Utilize um numero inteiro positivo.', 'error')
            return redirect(url_for('cluster'))
        else:
            output = ClusterProcessor.processCluster(session['username'], centers)
            return render_template('cluster.html',username=session['username'],outputContainer = output, has_file = session['has_cluster_file'], module_name = 'Cluster')



###############
#### ADMIN ####
###############
@app.route('/admin')
def admin():
    if 'username' in session:
        return render_template('admin.html', has_file = session['has_upload_index_file'], username=session['username'], module_name = 'Administrador')
    return redirect(url_for('login'))



@app.route('/uploadindexvalues', methods=['GET', 'POST'])
def upload_index_values():
    if request.method == 'POST':
        f = request.files['index_file']
        UserFilesController.saveUserUploadedFile(session['username'], f, UserFilesController.FileType.INDEX_UPLOAD)
        session['has_upload_index_file'] = True
    return redirect(url_for('admin'))

@app.route('/processUploadIndex', methods=['GET', 'POST'])
def process_upload_index():
    if request.method == 'POST':
        AdminUploader.processUploadIndex(session['username'])
        session['has_upload_index_file'] = False
    return redirect(url_for('admin'))


@app.route('/insertIndex', methods=['GET', 'POST'])
def insert_index():
    if request.method == 'POST':
        message = AdminUploader.insertNewIndex(request.form['index_symbol'], request.form['index_description'])
        flash(message)
    return redirect(url_for('admin'))


@app.route('/computeIndicators', methods=['GET', 'POST'])
def compute_indicators():
    if request.method == 'POST':
        dateStr = request.form['reference_date']
        date = datetime.strptime(dateStr,"%Y-%m-%d")
        message = ComputeIndicatorsProcessor.computeCalculatedIndicators(date)
        flash(message)
    return redirect(url_for('admin'))    
    
    
##################
#### ANALYSIS ####
##################
@app.route('/analysis')
def analysis():
    if 'username' in session:
        return render_template('analysis.html', username=session['username'], module_name = 'Analises')
    return redirect(url_for('login'))

###################
#### RESEARCHS ####
###################

@app.route('/researchFund')
def research_fund():
    if 'username' in session:
        return render_template('researchFund.html', username=session['username'], module_name = 'Consulta Fundos')
    return redirect(url_for('login'))

@app.route('/searchFund', methods=['GET', 'POST'])
def search_fund():
    if request.method == 'POST':
        container = SearchProcessor.searchFund(request.form['search_cnpj'])
        lastComputedItems = SearchProcessor.searchLastComputedDataItemsForFund(container.fund.fundId)
        return render_template('researchFund.html',username=session['username'], outputContainer = container, module_name = 'Consulta Fundos', last_computed_items = lastComputedItems)


@app.route('/researchBench')
def research_bench():
    if 'username' in session:
        return render_template('researchBench.html', username=session['username'], module_name = 'Consulta Indices')
    return redirect(url_for('login'))

@app.route('/searchBench', methods=['GET', 'POST'])
def search_bench():
    if request.method == 'POST':
        container = SearchProcessor.searchBenchmark(request.form['search_symbol'])
        return render_template('researchBench.html',username=session['username'], outputContainer = container, module_name = 'Consulta Indices')

#################
#### REPORTS ####
#################
@app.route('/reports')
def reports():
    if 'username' in session:
        return render_template('reports.html', has_file = session['has_report_parameters_file'], username=session['username'], module_name = 'Relatorios')
    return redirect(url_for('login'))


@app.route('/uploadReportParameters', methods=['GET', 'POST'])
def upload_reportparameter():
    if request.method == 'POST':
        f = request.files['report_parameters_file']
        UserFilesController.saveUserUploadedFile(session['username'], f, UserFilesController.FileType.REPORT_PARAMETERS_UPLOAD)
        session['has_report_parameters_file'] = True
    return redirect(url_for('reports'))

@app.route('/uploadanotherreportparameter', methods=['GET', 'POST'])
def upload_anotherreportparameter():
    session['has_report_parameters_file'] = False
    return redirect(url_for('reports'))

@app.route('/processReport', methods=['GET', 'POST'])
def process_report():
    if request.method == 'POST':
        output = ReportProcessor.processReport(session['username'])
        return render_template('reports.html',username=session['username'],outputContainer = output, has_file = session['has_report_parameters_file'], module_name = 'Relatorios')



#####################
#### APP RUNNING ####
#####################

# SET THE SECRET KEY
app.secret_key = 'VAIPALMEIRASA0Zr98j/3yX R~XHH!jmN]LWX/,?RT'


#RUN
if __name__ == '__main__':
    app.run(host='0.0.0.0', debug=True)
