package br.org.usp.ime.corsini.robot.collector;

import java.io.BufferedInputStream;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.net.HttpURLConnection;
import java.net.URL;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.zip.ZipEntry;
import java.util.zip.ZipInputStream;


/**
 * @author jose.corsini
 *
 */
public class BenchmarkCollector extends Collector{

	/**
	 * Coleta o ndice ibovespa fechamento referente  uma determinada data
	 * @param date: data de referncia
	 * @param sourcePath: path de sada
	 * @return
	 * @throws Exception
	 */
	public String collect(Date date, String sourcePath) throws Exception
	{

		//URL para download
		String stringURL = "http://www.bmfbovespa.com.br/fechamento-pregao/bdi/bdi" + new SimpleDateFormat("MMdd").format(date) + ".zip";
		URL url = new URL(stringURL);
		
		HttpURLConnection conn = null;
		BufferedInputStream bis = null;
		String completePath = "";
		try {
			conn = (HttpURLConnection) url.openConnection();
			conn.setUseCaches(false);

			//Abre o arquivo zip
			ZipInputStream zis = new ZipInputStream(conn.getInputStream());
			ZipEntry entry = zis.getNextEntry();
			if(!entry.getName().equals("BDIN"))
			{
				return null;
			}

			String fileName = getStartFileName() + entry.getName();
			ByteArrayOutputStream baos = new ByteArrayOutputStream();
			copiarArquivo(zis, baos);
			
			//Salva o arquivo
			completePath = sourcePath + "\\" +  fileName + "_" + new SimpleDateFormat("yyyyMMdd").format(date);
			File f = new File(completePath);
			FileOutputStream fos = new FileOutputStream(f);
			fos.write(baos.toByteArray());
			fos.flush();
			fos.close();
		} catch (IOException e) {
			//Log
			e.printStackTrace();
		} finally {
			if (bis != null) {
				try {
					bis.close();
				} catch (IOException e) {
					e.printStackTrace();
				}
			}
			if (conn != null) {
				conn.disconnect();
			}
		}		
		return completePath;
	}


	protected String getStartFileName() {
		return "\\benchmark_values_";
	}



}