package br.org.usp.ime.corsini.robot.collector;

import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;

/**
 * @author jose.corsini
 *
 */
public class BovespaLoader extends BenchmarkLoader{
	
	private static final String IBOVESPA_SYMBOL = "IBOVESPA";
	
	/**
	 *	Busca o ndice referente ao fechamento do ibovespa e persiste o valor 
	 * @param completePath
	 * @throws ParseException
	 */
	public void load(String completePath) throws ParseException{
		
		try {
	        BufferedReader in = new BufferedReader(new FileReader(completePath));

	        Date date = null;
	        while(in.ready()) {
	        	
	        	String line = in.readLine();
	        	
				//GETTING DATE
				if (line.startsWith("00", 0))
				{
					String dateString = line.substring(30, 38);
					date = new SimpleDateFormat("yyyyMMdd").parse(dateString);
				}
	        	
	        	
	        	
	        	//INDEX BOVESPA MAPPING
				Double value = null;
	        	if (line.startsWith("01", 0))
				{
	        		//INDEX CODE
	        		String code = line.substring(4, 34).trim();
	        		if(code.equals(IBOVESPA_SYMBOL))
	        		{
	        			//CLOSING VALUE
	        			String close = line.substring(92, 98);
	        			value = Double.parseDouble(close);
	        		}
				}
	        	
        	
	        	if(date != null && value != null)
	        	{
	        		persistValue(IBOVESPA_SYMBOL, date, value);
	        	}
	        }
	        in.close();
	        
	    } catch (IOException e) {
	    	e.printStackTrace();
	    }
	}
}
