package br.org.usp.ime.corsini.robot.collector;

import java.io.BufferedInputStream;
import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileOutputStream;
import java.io.FileReader;
import java.io.IOException;
import java.io.OutputStreamWriter;
import java.net.HttpURLConnection;
import java.net.URL;
import java.rmi.RemoteException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.zip.ZipEntry;
import java.util.zip.ZipInputStream;

import javax.xml.rpc.ServiceException;

import br.gov.cvm.webServices.WsDownloadInfsLocator;
import br.gov.cvm.webServices.WsDownloadInfsSoap;

/**
 * @author jose.corsini
 *
 */
public abstract class CvmFundCollector extends Collector {

	protected static final String CVM_DATE_FORMAT = "yyyy-MM-dd";

	protected static final String FILE_DATE_FORMAT = "yyyyMdd";

	protected WsDownloadInfsSoap getSoap() throws RemoteException, ServiceException
	{
		WsDownloadInfsLocator service = new WsDownloadInfsLocator();
		WsDownloadInfsSoap soap;
		soap = service.getWsDownloadInfsSoap();
		soap.login(WebServiceInfo.USER_ID, WebServiceInfo.PASSWORD);
		return soap;
	}

	/**
	 * Coleta as informaes no web service CVM
	 * @param date
	 * @param sourcePath
	 * @param cleanFile
	 * @return
	 * @throws Exception
	 */
	public String collect(Date date, String sourcePath, boolean cleanFile) throws Exception
	{
		String completePath = "";
		SimpleDateFormat sdf = new SimpleDateFormat(CVM_DATE_FORMAT);

		WsDownloadInfsSoap soap = getSoap();

		URL url = new URL(getStringURL(soap, sdf.format(date)));
		System.out.println("\r\nEfetuando download: " + url);

		HttpURLConnection conn = null;
		BufferedInputStream bis = null;
		try {
			conn = (HttpURLConnection) url.openConnection();
			conn.setUseCaches(false);

			ZipInputStream zis = new ZipInputStream(conn.getInputStream());
			ZipEntry entry = zis.getNextEntry();
			sdf = new SimpleDateFormat(FILE_DATE_FORMAT);
			if(!entry.getName().equals( sdf.format(date) + ".xml"))
			{
				return null;
			}

			String fileName = getStartFileName() + entry.getName();
			ByteArrayOutputStream baos = new ByteArrayOutputStream();
			copiarArquivo(zis, baos);


			completePath = sourcePath + "\\" +  fileName;
			File f = new File(completePath);
			FileOutputStream fos = new FileOutputStream(f);
			fos.write(baos.toByteArray());
			fos.flush();
			fos.close();
			
			if(cleanFile)
			{
				completePath = limpaArquivo(sourcePath, fileName);
			}

		} catch (IOException e) {
			//Log
			e.printStackTrace();
		} finally {
			if (bis != null) {
				try {
					bis.close();
				} catch (IOException e) {
					e.printStackTrace();
				}
			}
			if (conn != null) {
				conn.disconnect();
			}
		}

		return completePath;
	}


	/**
	 * Limpa o arquivo, isto , remove caracteres que geram problema
	 * @param rootPath
	 * @param fileName
	 * @return
	 * @throws IOException
	 */
	private String limpaArquivo(String rootPath, String fileName) throws IOException
	{
		System.out.println("\r\nLimpando arquivo...");
		FileReader reader = new FileReader(rootPath + "\\" + fileName);  
		BufferedReader in = new BufferedReader(reader);

		String cleanedPath = rootPath + "\\cleaned_" + fileName;
		BufferedWriter bw = new BufferedWriter(new OutputStreamWriter(  
                new FileOutputStream(cleanedPath), "UTF8"));

		while (in.ready()){  
			bw.append(cleanLine(in.readLine()));
		} 

		bw.flush();
		bw.close();
		reader.close();  
		
		return cleanedPath;
	}
	
	
	/**
	 * Limpa uma determinada linha
	 * @param line
	 * @return
	 */
	private String cleanLine(String line)
	{
		String cleaned = line.replace("", "");
		cleaned = cleaned.replace("&#x7;", "");
		return cleaned;
	}

	protected abstract String getStringURL(WsDownloadInfsSoap soap, String dateText) throws RemoteException;

	protected abstract String getStartFileName();

}
