package br.org.usp.ime.corsini.robot.loader.entities;

import java.io.Serializable;
import java.util.Date;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.Query;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;

import br.org.usp.ime.corsini.robot.persistence.EntityManagerHelper;

@Entity
@Table(name = "benchmark_value")
@NamedQueries(value = {
		@NamedQuery(name = "BenchmarkValue.findByBenchmarkAndDate", query = "select bv from BenchmarkValue bv where bv.benchmark = :benchmark and bv.date = :date")})


public class BenchmarkValue implements Serializable {

	private static final long serialVersionUID = -8654189272261440374L;
		
	@Id
	@GeneratedValue(strategy = GenerationType.AUTO)
	private int id;

	@ManyToOne(optional = false, fetch = FetchType.LAZY)
	@JoinColumn(name = "benchmark_id", nullable = false)
	private Benchmark benchmark;
	
	@Column(nullable = false)
	@Temporal(TemporalType.DATE)
	private Date date;

	@Column(nullable = false)
	private Double value;
	
	
	public Benchmark getBenchmark() {
		return benchmark;
	}


	public void setBenchmark(Benchmark benchmark) {
		this.benchmark = benchmark;
	}


	public Date getDate() {
		return date;
	}


	public void setDate(Date date) {
		this.date = date;
	}


	public Double getValue() {
		return value;
	}


	public void setValue(Double value) {
		this.value = value;
	}


	public int getId() {
		return id;
	}


	public boolean validate()
	{
		if(benchmark == null || date == null || value == null)
		{
			return false;
		}
		
		if(value <= 0)
		{
			return false;
		}
		
		return true;
	}
	
	
	public static Query getQueryFindByBenchmarkAndDate()
	{
		return EntityManagerHelper.getQuery("BenchmarkValue.findByBenchmarkAndDate");
	}


	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result
				+ ((benchmark == null) ? 0 : benchmark.hashCode());
		result = prime * result + ((date == null) ? 0 : date.hashCode());
		result = prime * result + ((value == null) ? 0 : value.hashCode());
		return result;
	}


	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		BenchmarkValue other = (BenchmarkValue) obj;
		if (benchmark == null) {
			if (other.getBenchmark() != null)
				return false;
		} else if (!benchmark.equals(other.getBenchmark()))
			return false;
		if (date == null) {
			if (other.getDate() != null)
				return false;
		} else if (!date.equals(other.getDate()))
			return false;
		if (value == null) {
			if (other.getValue() != null)
				return false;
		} else if (!value.equals(other.getValue()))
			return false;
		return true;
	}
	
	
	
	
}
	
