package br.org.usp.ime.corsini.robot.loader.entities;

import java.io.Serializable;
import java.util.Date;

import javax.persistence.*;

import br.org.usp.ime.corsini.robot.persistence.EntityManagerHelper;

/**
 * Entity implementation class for Entity: Fund
 *
 */
@Entity
@Table(name = "fund")
@NamedQueries(value = {
		@NamedQuery(name = "Fund.findByCnpj", query = "select f from Fund f where f.cnpj = :cnpj")})
public class Fund implements Serializable {

	private static final long serialVersionUID = -2849338391579751279L;
	
	@Id
	@GeneratedValue(strategy = GenerationType.AUTO)
	private int id;
	
	@Column(nullable = false)
	private Long cnpj;
	
	@Column(nullable = false)
	private String name;
	
	@Column(name="start_date", nullable = false)
	private Date start;
	
	@Column(nullable = false)
	private String category;
	
	@Column(name="category_start")
	private Date categoryStart;
	
	@Column
	private Boolean exclusive;


	public Fund() {
		
	}   
	
	public Fund(Long cnpj, String name) {
		this.cnpj = cnpj;
		this.name = name;
	}



	public int getId() {
		return this.id;
	}

	public Long getCnpj() {
		return this.cnpj;
	}

	public void setCnpj(long cnpj) {
		this.cnpj = cnpj;
	}   
	public String getName() {
		return this.name;
	}

	public void setName(String name) {
		this.name = name;
	}
	
	public Date getStart() {
		return start;
	}

	public void setStart(Date start) {
		this.start = start;
	}

	public String getCategory() {
		return category;
	}

	public void setCategory(String category) {
		this.category = category;
	}

	public Date getCategoryStart() {
		return categoryStart;
	}

	public void setCategoryStart(Date categoryStart) {
		this.categoryStart = categoryStart;
	}

	public Boolean getExclusive() {
		return exclusive;
	}

	public void setExclusive(Boolean exclusive) {
		this.exclusive = exclusive;
	}
	
	public static Query getQueryFindByCnpj()
	{
		return EntityManagerHelper.getQuery("Fund.findByCnpj");
	}

	public boolean validate() {
		if(cnpj == null || name == null || start == null || category == null)
		{
			return false;
		}
		
		return true;
	}

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result
				+ ((category == null) ? 0 : category.hashCode());
		result = prime * result
				+ ((categoryStart == null) ? 0 : categoryStart.hashCode());
		result = prime * result + ((cnpj == null) ? 0 : cnpj.hashCode());
		result = prime * result
				+ ((exclusive == null) ? 0 : exclusive.hashCode());
		result = prime * result + ((name == null) ? 0 : name.hashCode());
		result = prime * result + ((start == null) ? 0 : start.hashCode());
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (!(obj instanceof Fund))
			return false;
		Fund other = (Fund) obj;
		if (category == null) {
			if (other.getCategory() != null)
				return false;
		} else if (!category.equals(other.getCategory()))
			return false;
		if (categoryStart == null) {
			if (other.getCategoryStart() != null)
				return false;
		} else if (!categoryStart.equals(other.getCategoryStart()))
			return false;
		if (cnpj == null) {
			if (other.getCnpj() != null)
				return false;
		} else if (!cnpj.equals(other.getCnpj()))
			return false;
		if (exclusive == null) {
			if (other.getExclusive() != null)
				return false;
		} else if (!exclusive.equals(other.getExclusive()))
			return false;
		if (name == null) {
			if (other.getName() != null)
				return false;
		} else if (!name.equals(other.getName()))
			return false;
		if (start == null) {
			if (other.getStart() != null)
				return false;
		} else if (!start.equals(other.getStart()))
			return false;
		return true;
	}
}