package br.org.usp.ime.corsini.robot.loader.entities;

import java.io.Serializable;
import java.util.Date;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.Query;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;

import br.org.usp.ime.corsini.robot.persistence.EntityManagerHelper;

/**
 * Entity implementation class for Entity: FundQuota
 *
 */
@Entity
@Table(name = "fund_quota")
@NamedQueries(value = {
		@NamedQuery(name = "FundQuota.findByFundAndDate", query = "select fq from FundQuota fq where fq.fund = :fund and fq.date = :date")})
public class FundQuota implements Serializable {
	
	private static final long serialVersionUID = -5455126472395700897L;

	@Id
	@GeneratedValue(strategy = GenerationType.AUTO)
	private int id;

	@ManyToOne(optional = false, fetch = FetchType.LAZY)
	@JoinColumn(name = "fund_id", nullable = false)
	private Fund fund;
	
	@Column(nullable = false)
	@Temporal(TemporalType.DATE)
	private Date date;

	@Column(nullable = false)
	private Double quota;

	@Column(name = "net_asset")
	private Double netAsset;

	public int getId() {
		return id;
	}

	public Fund getFund() {
		return fund;
	}

	public Date getDate() {
		return date;
	}

	public Double getQuota() {
		return quota;
	}
	
	public Double getNetAsset() {
		return netAsset;
	}

	public void setFund(Fund fund) {
		this.fund = fund;
	}

	public void setDate(Date date) {
		this.date = date;
	}

	public void setQuota(Double quota) {
		this.quota = quota;
	}

	public void setNetAsset(Double netAsset) {
		this.netAsset = netAsset;
	}
	
	
	public boolean validate()
	{
		if(fund == null || date == null || quota == null || netAsset == null)
		{
			return false;
		}
		
		if(quota <= 0 || netAsset <= 0)
		{
			return false;
		}
		
		return true;
	}
	
	public static Query getQueryFindByFundAndDate()
	{
		return EntityManagerHelper.getQuery("FundQuota.findByFundAndDate");
	}

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + ((date == null) ? 0 : date.hashCode());
		result = prime * result + ((fund == null) ? 0 : fund.hashCode());
		result = prime * result
				+ ((netAsset == null) ? 0 : netAsset.hashCode());
		result = prime * result + ((quota == null) ? 0 : quota.hashCode());
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (!(obj instanceof FundQuota))
			return false;
		FundQuota other = (FundQuota) obj;
		if (date == null) {
			if (other.getDate() != null)
				return false;
		} else if (!date.equals(other.getDate()))
			return false;
		if (fund == null) {
			if (other.getFund() != null)
				return false;
		} else if (!fund.equals(other.getFund()))
			return false;
		if (netAsset == null) {
			if (other.netAsset != null)
				return false;
		} else if (!netAsset.equals(other.netAsset))
			return false;
		if (quota == null) {
			if (other.quota != null)
				return false;
		} else if (!quota.equals(other.quota))
			return false;
		return true;
	}
}
