package br.org.usp.ime.corsini.robot.main;

import java.util.Calendar;
import java.util.Date;

import org.quartz.Job;
import org.quartz.JobExecutionContext;
import org.quartz.JobExecutionException;

import br.org.usp.ime.corsini.robot.collector.BenchmarkCollector;
import br.org.usp.ime.corsini.robot.collector.BovespaLoader;
import br.org.usp.ime.corsini.robot.collector.CvmFundInfoCollector;
import br.org.usp.ime.corsini.robot.collector.CvmFundInfoLoader;
import br.org.usp.ime.corsini.robot.collector.CvmFundQuotaAnualCollector;
import br.org.usp.ime.corsini.robot.collector.CvmFundQuotaColletor;
import br.org.usp.ime.corsini.robot.collector.CvmFundQuotaLoader;


/**
 * @author jose.corsini
 *
 */
public class RobotJob implements Job {

	//FILES PATH
	private static final String rootPath = "C:\\arquivos";
	
	/**
	 * Executa as tarefas
	 */
	@Override
	public void execute(JobExecutionContext context) throws JobExecutionException {

		try
		{
			Calendar calendar = Calendar.getInstance();  
			System.out.println("Rodando em: " + calendar.getTime()); // data de hoje  
			  
			  
			calendar.add(Calendar.DAY_OF_WEEK, -3); //ajustado para buscar 3 dias atrs
			Date d = calendar.getTime();
			System.out.println("Data ref: " + d); 
			
			System.out.println("Collecting benchmark...");
			collectBenchmark(d);
			System.out.println("Fund Info...");
			collectAndPersistFundInfo(d);
			System.out.println("Fund Quota...");
			collectAndPersistQuota(d);
			//collectAndPersistAnual(d);
		}catch (Exception e) {
			System.out.println("Erro na coleta");
			e.printStackTrace();
		}
	}

	/**
	 * Coleta e persiste benchmark
	 */
	private void collectBenchmark(Date date)
	{
		try {
			String completePath = new BenchmarkCollector().collect(date, rootPath);
			new BovespaLoader().load(completePath);
		} catch (Exception e) {
			e.printStackTrace();
		}
	}


	/**
	 * Coleta e persiste informaes de fundo
	 */
	private void collectAndPersistFundInfo(Date date)
	{
		try {
			String completePath = new CvmFundInfoCollector().collect(date, rootPath, true);
			new CvmFundInfoLoader().load(completePath);
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	/**
	 * Coleta e persiste cotas dos fundos
	 */
	private void collectAndPersistQuota(Date date)
	{
		try {
			String completePath = new CvmFundQuotaColletor().collect(date, rootPath, false);
			new CvmFundQuotaLoader().loadDailyInformation(completePath);

		} catch (Exception e) {
			e.printStackTrace();
		} 
	}

	/**
	 * Coleta e persiste valores anuais
	 */
	@SuppressWarnings("unused")
	private void collectAndPersistAnual(Date date){
		try {
			String path = new CvmFundQuotaAnualCollector().collect(date, rootPath, false);
			new CvmFundQuotaLoader().loadAnnualInformation(path);
		} catch (Exception e) {
			e.printStackTrace();
		} 
	}
}
